==> haskell-warp-tls-3.2.5-20-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-warp-tls.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: warp-tls
version: 3.2.5
id: warp-tls-3.2.5-1lZaK7jCr4vHSA8pGe8Vmi
key: warp-tls-3.2.5-1lZaK7jCr4vHSA8pGe8Vmi
license: MIT
maintainer: michael@snoyman.com
author: Michael Snoyman
stability: Stable
homepage: http://github.com/yesodweb/wai
synopsis: HTTP over TLS support for Warp via the TLS package
description:
    SSLv1 and SSLv2 are obsoleted by IETF.
    We should use TLS 1.2 (or TLS 1.1 or TLS 1.0 if necessary).
    HTTP/2 can be negotiated by ALPN.
    API docs and the README are available at
    <http://www.stackage.org/package/warp-tls>.
category: Web, Yesod
abi: ac16938dea65f87b585a0037be3819bd
exposed: True
exposed-modules:
    Network.Wai.Handler.WarpTLS
import-dirs: /usr/lib/ghc-8.6.5/site-local/warp-tls-3.2.5
library-dirs: /usr/lib/ghc-8.6.5/site-local/warp-tls-3.2.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/warp-tls-3.2.5
hs-libraries: HSwarp-tls-3.2.5-1lZaK7jCr4vHSA8pGe8Vmi
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    cryptonite-0.26-5pCtI3fv84M4lNt7lObUcf
    data-default-class-0.1.2.0-1aigY0ifYUs4kfvMygEld7
    network-2.8.0.0-A0G1UJzDIGiEvzFah0DnI2
    streaming-commons-0.2.1.0-HgshHrAW4sJ7tnvtY46l5k
    tls-1.4.1-Dmqkt8rQMAcIZchag7VhWU
    tls-session-manager-0.0.0.2-CRGCqWDmOrA2OBraCdnul7
    wai-3.2.2-GlQJpLVznLECwkQpTtQzT9 warp-3.2.27-FuHRsgMulsMHzqT9UIG7H8
haddock-interfaces: /usr/share/doc/haskell-warp-tls/html/warp-tls.haddock
haddock-html: /usr/share/doc/haskell-warp-tls/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-warp-tls-3.2.5-24-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-warp-tls.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: warp-tls
version: 3.2.5
id: warp-tls-3.2.5-EebrFGDlTIfCWkIt0fSB7r
key: warp-tls-3.2.5-EebrFGDlTIfCWkIt0fSB7r
license: MIT
maintainer: michael@snoyman.com
author: Michael Snoyman
stability: Stable
homepage: http://github.com/yesodweb/wai
synopsis: HTTP over TLS support for Warp via the TLS package
description:
    SSLv1 and SSLv2 are obsoleted by IETF.
    We should use TLS 1.2 (or TLS 1.1 or TLS 1.0 if necessary).
    HTTP/2 can be negotiated by ALPN.
    API docs and the README are available at
    <http://www.stackage.org/package/warp-tls>.
category: Web, Yesod
abi: d2e4e95c9db1bba6981145bebd97a442
exposed: True
exposed-modules:
    Network.Wai.Handler.WarpTLS
import-dirs: /usr/lib/ghc-8.6.5/site-local/warp-tls-3.2.5
library-dirs: /usr/lib/ghc-8.6.5/site-local/warp-tls-3.2.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/warp-tls-3.2.5
hs-libraries: HSwarp-tls-3.2.5-EebrFGDlTIfCWkIt0fSB7r
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    cryptonite-0.26-5pCtI3fv84M4lNt7lObUcf
    data-default-class-0.1.2.0-1aigY0ifYUs4kfvMygEld7
    network-2.8.0.0-EWiez0ajBalJ2cORFP4yEt
    streaming-commons-0.2.1.0-HmrzuoDyRxaA7jtrPjSoAN
    tls-1.4.1-UtXELbmKRkISZfsPdmvB8
    tls-session-manager-0.0.0.2-FjJzU5CqMqY7h6aEd2Klof
    wai-3.2.2-FKI9I9MeRyhBwlVDOn737X warp-3.2.27-EnnuUbTHmIYOaOhzBXl5W
haddock-interfaces: /usr/share/doc/haskell-warp-tls/html/warp-tls.haddock
haddock-html: /usr/share/doc/haskell-warp-tls/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
